@@ -1,4 +1,4 @@
-// Copyright (C) 2018-2024 Internet Systems Consortium, Inc. ("ISC")
+// Copyright (C) 2018-2025 Internet Systems Consortium, Inc. ("ISC")
 //
 // This Source Code Form is subject to the terms of the Mozilla Public
 // License, v. 2.0. If a copy of the MPL was not distributed with this
@@ -427,6 +427,9 @@ HostDataSourceUtils::compareOptions(const ConstCfgOptionPtr& cfg1,
                 EXPECT_FALSE(ctx2);
             }
 
+            // Compare client classes.
+            EXPECT_EQ(desc1.client_classes_, desc2.client_classes_);
+
             // Retrieve options.
             Option* option1 = desc1.option_.get();
             Option* option2 = desc2.option_.get();
